@@ -1,3 +1,4 @@
+use crate::patterns::callbacks::MyCallback;
 use crate::patterns::result::{Error, FFIError};
 use interoptopus::patterns::primitives::FFIBool;
 use interoptopus::patterns::slice::{FFISlice, FFISliceMut};
@@ -36,6 +37,15 @@ impl SimpleService {
         })
     }
 
+    #[ffi_service_ctor]
+    pub fn new_with_string(ascii: AsciiPointer) -> Result<Self, Error> {
+        Ok(Self {
+            some_value: 0,
+            c_string: ascii.as_c_str().unwrap().into(),
+            data: vec![1, 2, 3],
+        })
+    }
+
     #[ffi_service_ctor]
     pub fn new_failing(_some_value: u8) -> Result<Self, Error> {
         Err(Error::Bad)
@@ -115,6 +125,11 @@ impl SimpleService {
     pub fn method_void_ffi_error(&mut self) -> Result<(), Error> {
         Ok(())
     }
+
+    pub fn method_callback(&mut self, callback: MyCallback) -> Result<(), Error> {
+        callback.call(0);
+        Ok(())
+    }
 }
 
 // Some struct we want to expose as a class.
